function X = bjorling(m1,m2,k1,k2,rho1,rho2)
%constructs a function handle for the potential that solve the Bjorling
%problem for Willmore surfaces with mu=m1+i*mu2, k=k1+i*k2,
%rho=rho1+i*rho2.  Use with WdpwB
%input:  All inputs are function handles of form @(t)f(t),
%where f(z) should be an analytic function

rho=@(t)rho1(t)+1i*rho2(t);

X=@(z)[(1/(2*sqrt(2)))*[0               0               1+conj(rho(z))    1i*(1+conj(rho(z)))  0;
                     0                0               1-conj(rho(z))    1i*(1-conj(rho(z)))  0;
                     1+conj(rho(z))      -1+conj(rho(z))          0              0           0;
                     1i*(1+conj(rho(z)))  -1i*(1-conj(rho(z)))      0              0           0;
                     0                0               0               0          0],...
    [0     m1(z)     0      0       0;
       m1(z)   0        0      0       0;
       0       0        0     -m2(z)  -2*k1(z);
       0       0       m2(z)   0       2*k2(z);
       0       0       2*k1(z)  -2*k2(z)   0],...
    (1/(2*sqrt(2)))*[0               0               1+rho(z)    -1i*(1+rho(z))  0;
                     0                0               1-rho(z)    -1i*(1-rho(z))  0;
                     1+rho(z)      -1+rho(z)          0              0           0;
                     -1i*(1+rho(z))  1i*(1-rho(z))      0              0           0;
                     0                0               0               0          0]];

end